sapply(c('ggplot2','beeswarm','xlsx','reshape2','ggplot2bdc'), require, character.only = TRUE)

#Figure 1
F1 <- read.csv("F1-checkerboard.csv")
plot.F1a = 
  ggplot(data=F1, aes(x=Col, y=Row)) +
  geom_point(size=12, aes(color=as.numeric(Bug))) +
  coord_fixed(ratio=(13/12)/(9/8), xlim=c(0.5, 12.5), ylim=c(0.5, 8.5)) +
  scale_y_reverse(breaks=seq(1, 8), labels=LETTERS[1:8]) +
  scale_x_continuous(breaks=seq(1, 12)) +
  scale_colour_gradientn(colours = c("5","2")) +
  labs(title="Contamination Experiment: Plate Layout") +
  theme_bdc_microtiter()
#plot.F1b =
  beeswarm(Abs~Bug, data = F1, pch = 16, size=15,pwcol = 5 + -3*as.numeric(Bug), main= "Contamination after 24 Hrs", corral="wrap", ylab="Absorbance (OD, 160 µl)", xlab="S. mutans added...", ylim=c(0,.55))
  boxplot(Abs ~ Bug, data = F1, outline = FALSE, add=T, col="#00000000")

#Figure 2
F2 <- read.csv("F2-planktoniccsv.csv")
  colnames(F2)[4:5]=c("Sig","Conc")
  F2$Conc=F2$Conc/1000    # Convert mg/L to g/L
  levels(F2$User)=c('Automated','Manual')
F2.fit.manual <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F2[F2$User=="Manual",], start=list(d=0.5, a=.05, cc=-3),  trace=TRUE)
F2.fit.automated <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F2[F2$User=="Automated",], start=list(d=0.5, a=.05, cc=-3),  trace=TRUE)
F2.fit.param=rbind(data.frame(Conc=10^coef(F2.fit.automated)["cc"],
                              Sig=predict(F2.fit.automated,list(Conc=10^coef(F2.fit.automated)["cc"])),
                              User='Automated',
                              CLow=10^(coef(F2.fit.automated)["cc"]+0.3),
                              CHi=10^(coef(F2.fit.automated)["cc"]-0.3)),
                   data.frame(Conc=10^coef(F2.fit.manual)["cc"],
                              Sig=predict(F2.fit.manual,list(Conc=10^coef(F2.fit.manual)["cc"])),
                              User='Manual',
                              CLow=10^(coef(F2.fit.manual)["cc"]-0.3),
                              CHi=10^(coef(F2.fit.manual)["cc"]+0.3)))
print(paste0("The IC50 for (automated) planktonic toxicity is at ",10^coef(F2.fit.automated)["cc"]," mg/L (± 30% in logspace)"))
print(paste0("The IC50 for (manual) planktonic toxicity is at ",10^coef(F2.fit.manual)["cc"]," mg/L (± 30% in logspace)"))
plot.F2=
  ggplot(F2,aes(x=Conc,y=Sig,shape=User)) + facet_grid(User~.,scales='free_y') + 
  geom_smooth(method='nls', formula= y ~ d+(a-d)/(1+(x/cc)^-30), start=c(d=0.05, a=.5, cc=-3), se=FALSE, control=c(maxiter=500),
              linetype='solid',color='black') +
  geom_line(aes(group=Conc),color='grey') + geom_point(color='red') + 
  geom_point(data=F2.fit.param,aes(x=Conc,y=Sig),color='black',size=3,shape=15) +
  geom_errorbarh(data=F2.fit.param,aes(xmin=CLow,xmax=CHi),color='black',height=0) +
  scale_x_log10(breaks=10^c(-5:1)) + annotation_logticks(base = 10, sides="b") +
  labs(title="Planktonic CPC Activity",y="Optical Density (AU)",x="[CPC] (g/L)") + theme(legend.position='none',panel.grid.minor=element_blank())

# Figure 3
XttSig <- function(df) {   # Function assumes collumn names: Abs450, Abs630, Conc, Bug. Function assigns new columns: AbsDiff, Sig.
  df$AbsDiff=df$Abs450-df$Abs630
  df$Sig=0
  for(i in df$Conc) {df[df$Conc==i,]$Sig = df[df$Conc==i,]$AbsDiff - mean(df[df$Conc==i & df$Bug==FALSE,]$AbsDiff)}
  return(df)
}
F3man <- data.frame(Abs630=melt(read.xlsx("F3-cpcbf.xlsx", sheetName="630", rowIndex=c(23:31))[,2:13])$value)
  F3man$Abs450 <- melt(read.xlsx("F3-cpcbf.xlsx", sheetName="450", rowIndex=c(23:31))[2:13])$value
  F3man$Conc=rep(1/3^(0:11),each=8)   # in g/L
  F3man$Bug=c(rep(TRUE,4),rep(FALSE,4))
  F3man$User='Manual'
  F3man=XttSig(F3man)
  F3man=F3man[F3man$Bug==TRUE,]
F3auto <- na.omit(read.xlsx("F5-PlateReaderData02.xlsx", sheetName="M1", rowIndex=c(43:139)))
  F3auto$Bug=as.logical(F3auto$Bug)
  F3auto$Conc=F3auto$Conc*0.340   # Convert mM to g/L
  F3auto=XttSig(F3auto)
  F3auto=F3auto[F3auto$Bug==TRUE & F3auto$Conc>0,]
  F3auto$User='Automated'
ggplot(F3man,aes(x=Conc,y=Sig)) + geom_point() + facet_grid(User~.) + scale_x_log10(breaks=10^(-5:5)) 
ggplot(F3auto,aes(x=Conc,y=Sig)) + geom_point() + facet_grid(User~.) + scale_x_log10(breaks=10^(-5:5))
F3=rbind(F3man[,c(3,5,7)],F3auto[,c(7,13,12)])
F3.fit.manual <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F3man, start=list(d=0.7, a=.1, cc=-2.5),  trace=TRUE)
F3.fit.automated <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F3auto, start=list(d=0.7, a=.1, cc=-2.5),  trace=TRUE)
F3.fit.param=rbind(data.frame(Conc=10^coef(F3.fit.automated)["cc"],
                              Sig=predict(F3.fit.automated,list(Conc=10^coef(F3.fit.automated)["cc"])),
                              User='Automated',
                              CLow=10^(coef(F3.fit.automated)["cc"]-0.3),
                              CHi=10^(coef(F3.fit.automated)["cc"]+0.3)),
                   data.frame(Conc=10^coef(F3.fit.manual)["cc"],
                              Sig=predict(F3.fit.manual,list(Conc=10^coef(F3.fit.manual)["cc"])),
                              User='Manual',
                              CLow=10^(coef(F3.fit.manual)["cc"]-0.3),
                              CHi=10^(coef(F3.fit.manual)["cc"]+0.3)))
print(paste0("The IC50 for (automated) 24 hr biofilm toxicity is at ",10^coef(F3.fit.automated)["cc"]," g/L (± 30% in logspace)"))
print(paste0("The IC50 for (manual) 24 hr biofilm toxicity is at ",10^coef(F3.fit.manual)["cc"]," g/L (± 30% in logspace)"))
plot.F3b=
  ggplot(F3,aes(x=Conc,y=Sig,shape=User)) + facet_grid(User~.,scales='free_y') + 
  geom_line(aes(group=Conc),color='grey') + geom_point(color='red') + 
  geom_smooth(method='nls', formula= y ~ d+(a-d)/(1+(x/cc)^-30), start=c(d=0.7, a=.1, cc=-2.5), se=FALSE, control=c(maxiter=500),
              linetype='solid',color='black') + 
  geom_point(data=F3.fit.param,aes(x=Conc,y=Sig),size=3,shape=15,color='black') +
  geom_errorbarh(data=F3.fit.param,aes(xmin=CLow,xmax=CHi),height=0,color='black') +
  scale_x_log10(breaks=10^c(-5:5)) + annotation_logticks(base = 10, sides="b") +
  labs(title="24 h Biofilm CPC Activity",y="Metabolic Activity",x="[CPC] (g/L)") + theme(legend.position='none',panel.grid.minor=element_blank())

F3a=read.csv("F3-xttdat.csv")
  F3a=F3a[F3a$Wash1=='Zero',]
  colnames(F3a)[4:6]=c('Abs450','Bug','Conc')
  levels(F3a$Bug)=c(FALSE,TRUE)
  F3a=XttSig(F3a)
  colnames(F3a)[6]='Time'
plot.F3a=
  ggplot(F3a, aes(y=Sig, x=as.numeric(Time),color=Bug,shape=Bug)) + 
  geom_boxplot(aes(group=interaction(Bug,Time)),position = position_dodge(width = 0),color='grey') + geom_point() +
  ggtitle("Measured Metabolic Activity") + xlab("Time (min)") + ylab("Absorbance (AU)") + scale_x_continuous(breaks=seq(0,150,25)) +
  theme(legend.position='none',panel.grid.minor=element_blank()) 

# Figure 4
F4P <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="P1", rowIndex=c(34:130)))
  F4P=F4P[F4P$Bug=="T" & F4P$Conc>0 & F4P$Conc<0.05,]
  F4P$Conc=F4P$Conc*0.340   # Convert mM to g/L
  F4P$Type='Planktonic'
F4BF <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="F1", rowIndex=c(43:139)))
  F4BF$Bug=as.logical(F4BF$Bug)
  F4BF=XttSig(F4BF)
  F4BF=F4BF[F4BF$Bug==TRUE & F4BF$Conc>0,]
  F4BF$Conc=F4BF$Conc*0.340   # Convert mM to g/L
  F4BF$Type='Biofilm Forming'
F4B24 <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="M1", rowIndex=c(43:139)))
  F4B24$Bug=as.logical(F4B24$Bug)
  F4B24=XttSig(F4B24)
  F4B24=F4B24[F4B24$Bug==TRUE & F4B24$Conc>0,]
  F4B24$Type='24 h Biofilm'
  F4B24$Conc=F4B24$Conc*0.340   # Convert mM to g/L
F4=rbind(F4P[,c(4,5,7,8)],F4BF[,c(7,9,10,12)],F4B24[,c(7,9,10,12)])
F4.fit.P <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F4P, start=list(d=0.6, a=.0, cc=-3.8),  trace=TRUE)
F4.fit.BF <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F4BF, start=list(d=0.6, a=0, cc=-4),  trace=TRUE)
F4.fit.B24 <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F4B24, start=list(d=0.5, a=0.1, cc=-2.2),  trace=TRUE)
F4.fit.param=rbind(data.frame(Conc=10^coef(F4.fit.P)["cc"],
                              Sig=predict(F4.fit.P,list(Conc=10^coef(F4.fit.P)["cc"])),
                              Type='Planktonic',
                              CLow=10^(coef(F4.fit.P)["cc"]-0.3),
                              CHi=10^(coef(F4.fit.P)["cc"]+0.3)),
                   data.frame(Conc=10^coef(F4.fit.BF)["cc"],
                              Sig=predict(F4.fit.BF,list(Conc=10^coef(F4.fit.BF)["cc"])),
                              Type='Biofilm Forming',
                              CLow=10^(coef(F4.fit.BF)["cc"]-0.3),
                              CHi=10^(coef(F4.fit.BF)["cc"]+0.3)),
                   data.frame(Conc=10^coef(F4.fit.B24)["cc"],
                              Sig=predict(F4.fit.B24,list(Conc=10^coef(F4.fit.B24)["cc"])),
                              Type='24 h Biofilm',
                              CLow=10^(coef(F4.fit.B24)["cc"]-0.3),
                              CHi=10^(coef(F4.fit.B24)["cc"]+0.3)))
print(paste0("The IC50 for (automated) Planktonic toxicity is at ",10^coef(F4.fit.P)["cc"]," g/L (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Biofiom Forming toxicity is at ",10^coef(F4.fit.BF)["cc"]," g/L (± 30% in logspace)"))
print(paste0("The IC50 for (automated) 24 h Biofilm toxicity is at ",10^coef(F4.fit.B24)["cc"]," g/L (± 30% in logspace)"))
plot.F4=
  ggplot(F4,aes(x=Conc,y=Sig, shape=Type)) + facet_grid(Type~.,scales='free_y') + 
  geom_line(aes(group=Conc),color='grey') + geom_point(color='red') + 
  geom_smooth(method='nls', formula= y ~ d+(a-d)/(1+(x/cc)^-30), start=c(d=0.5, a=0.05, cc=-2.5), se=FALSE, control=c(maxiter=500),
              linetype='solid',color='black') + 
  geom_point(data=F4.fit.param,aes(x=Conc,y=Sig),color='black',size=3,shape=15) +
  geom_errorbarh(data=F4.fit.param,aes(xmin=CLow,xmax=CHi),color='black',height=.0) +
  scale_x_log10(breaks=10^c(-5:5)) + annotation_logticks(base = 10, sides="b") +
  labs(title="Planktonic CPC Toxicity",y="Culture Growth",x="[CPC] (g/L)") + theme(legend.position='none',panel.grid.minor=element_blank())

# Figure 5:
F5Pcl <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="P1", rowIndex=c(34:130)))
F5Pbr <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="P2", rowIndex=c(34:130)))
F5Pi <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="P3", rowIndex=c(34:130)))
F5P=rbind(F5Pcl,F5Pbr,F5Pi)
  F5P=F5P[F5P$Bug=='T' & F5P$Conc>0 & F5P$Conc<.05,]
F5BFcl <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="F1", rowIndex=c(43:139)))
F5BFbr <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="F2", rowIndex=c(43:139)))
F5BFi <- na.omit(read.xlsx("F4-PlateReaderData01.xlsx", sheetName="F3", rowIndex=c(43:139)))
F5BF=rbind(F5BFcl,F5BFbr,F5BFi)
F5B24cl <- na.omit(read.xlsx("F5-PlateReaderData02.xlsx", sheetName="M1", rowIndex=c(43:139)))
F5B24br <- na.omit(read.xlsx("F5-PlateReaderData02.xlsx", sheetName="M2", rowIndex=c(43:139)))
F5B24i <- na.omit(read.xlsx("F5-PlateReaderData02.xlsx", sheetName="M3", rowIndex=c(43:139)))
F5B24=rbind(F5B24cl,F5B24br,F5B24i)
F5B=rbind(F5BF,F5B24)
  F5B$Bug=as.logical(F5B$Bug)
  F5B=XttSig(F5B)
  F5B=F5B[F5B$Bug==TRUE & F5B$Conc>0,]
F5=rbind(F5P[,c(4,5,7,8)],F5B[,c(7,9,10,12)])
  F5$Conc=F5$Conc/1000    # Convert mM to M
F5.fit.Pc <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='C' & F5$Type=='P',], start=c(d=0.5, a=.05, cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.Pb <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='B' & F5$Type=='P',], start=c(d=0.5, a=.05, cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.Pi <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='I' & F5$Type=='P',], start=c(d=0.5, a=.05, cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.BFc <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='C' & F5$Type=='F',], start=c(d=0.6, a=0., cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.BFb <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='B' & F5$Type=='F',], start=c(d=0.6, a=0., cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.BFi <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='I' & F5$Type=='F',], start=c(d=0.6, a=0., cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.B24c <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='C' & F5$Type=='M',], start=c(d=0.6, a=0.1, cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.B24b <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='B' & F5$Type=='M',], start=c(d=0.6, a=0.1, cc=-5),  trace=TRUE,control = list(maxiter = 500))
F5.fit.B24i <- nls(Sig ~ d+(a-d)/(1+(log(Conc,10)/cc)^-30), data=F5[F5$Tox=='I' & F5$Type=='M',], start=c(d=0.6, a=0.1, cc=-5),  trace=TRUE,control = list(maxiter = 500))
print(paste0("The IC50 for (automated) Planktonic toxicity of CPC is at ",10^coef(F5.fit.Pc)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Planktonic toxicity of CPB is at ",10^coef(F5.fit.Pb)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Planktonic toxicity of CPI is at ",10^coef(F5.fit.Pi)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Biofiom Forming toxicity of CPC is at ",10^coef(F5.fit.BFc)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Biofiom Forming toxicity of CPB is at ",10^coef(F5.fit.BFb)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) Biofiom Forming toxicity of CPI is at ",10^coef(F5.fit.BFi)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) 24 h Biofilm toxicity of CPC is at ",10^coef(F5.fit.B24c)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) 24 h Biofilm toxicity of CPB is at ",10^coef(F5.fit.B24b)["cc"]," M (± 30% in logspace)"))
print(paste0("The IC50 for (automated) 24 h Biofilm toxicity of CPI is at ",10^coef(F5.fit.B24i)["cc"]," M (± 30% in logspace)"))
ggplot(F5,aes(x=Conc,y=Sig)) + geom_point() + scale_x_log10() + facet_grid(Tox~Type)
  levels(F5$Tox)=c('CPC','CPB','CPI')
  levels(F5$Type)=c('Planktonic','Biofilm Forming','24 h Biofilm')
F5.fit=list(F5.fit.Pc,F5.fit.Pb,F5.fit.Pi,F5.fit.BFc,F5.fit.BFb,F5.fit.BFi,F5.fit.B24c,F5.fit.B24b,F5.fit.B24i)
F5.fit.param=data.frame(Conc=sapply(F5.fit, function(f) 10^summary(f)$coefficients[3,1]),
                        Sig=sapply(F5.fit, function(f) predict(f,c(Conc=10^summary(f)$coefficients[3,1]))),
                        Type=rep(levels(F5$Type),each=3),
                        Tox=rep(levels(F5$Tox),3),
                        CLow=sapply(F5.fit, function(f) 10^(summary(f)$coefficients[3,1]+.3)),
                        CHi=sapply(F5.fit, function(f) 10^(summary(f)$coefficients[3,1]-.3)))
plot.F5=
  ggplot(data=F5,aes(x=Conc,y=Sig,shape=Type,color=Tox,group=interaction(Tox,Type))) + 
  scale_x_log10(breaks=10^(-8:5)) + facet_grid(Tox~Type, scales='free_x') + annotation_logticks(base = 10, sides="b") + 
  geom_smooth(method='nls', formula= y ~ d+(a-d)/(1+(x/cc)^-30), start=c(d=0.5, a=.05, cc=-5), se=FALSE, control=c(maxiter=500),
              linetype='solid',color='black') +
  geom_line(aes(group=Conc),color='grey') + geom_point() +
  xlab('[Toxin] (M)') + ylab('Culture Growth (AU)') + theme(legend.position='none',panel.grid.minor=element_blank()) +
  geom_point(data=F5.fit.param,color='black',size=2,shape=15) +
  geom_errorbarh(data=F5.fit.param,aes(xmin=CLow,xmax=CHi,color=Tox),height=0,color='black')

# Figure export...
theme_set(theme_bw())
fig.theme = theme(title=element_blank(),
                  axis.title.x=element_blank(),
                  axis.text.x=element_blank(),
                  axis.title.y=element_blank(),
                  axis.text.y=element_blank(),
                  panel.border=element_rect(colour = "black", fill=NA),
                  legend.background=element_blank())
plot.F1a + fig.theme  # export to 453(wide), 475(high)
plot.F2 + fig.theme  # export to 453(wide), 475(high)
plot.F3a + fig.theme  # export to 453(wide), 475(high)
plot.F3b + fig.theme  # export to 453(wide), 475(high)
plot.F4 + fig.theme  # export to 453(wide), 475(high)
plot.F5 + fig.theme  # export to 453(wide), 475(high)
